@@ -43,6 +43,22 @@ class Client():
     logger.info(response.text)
     return response.text
 
+  def put(self, url='/', data={}):
+    querystring = self.token
+
+    payload = json.dumps(data).encode('utf-8')
+    headers = {'content-type': 'application/json'}
+
+    response = requests.request(
+      "PUT",
+      self.url+url,
+      data=payload,
+      headers=headers,
+      params=querystring
+    )
+    logger.info(response.text)
+    return response.text
+
   def get(self, url='/', data={}):
     querystring = self.token
 
